@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -34,6 +34,7 @@ from hypothesis import strategies as st
 from hypothesis.errors import InvalidArgument, ResolutionFailed
 from hypothesis.internal.compat import ForwardRef, typing_root_type
 from hypothesis.internal.conjecture.utils import many as conjecture_utils_many
+from hypothesis.strategies._internal.datetime import zoneinfo
 from hypothesis.strategies._internal.ipaddress import (
     SPECIAL_IPv4_RANGES,
     SPECIAL_IPv6_RANGES,
@@ -103,7 +104,11 @@ def is_typing_literal(thing):
         hasattr(typing, "Literal")
         and getattr(thing, "__origin__", None) == typing.Literal
         or hasattr(typing_extensions, "Literal")
-        and getattr(thing, "__origin__", None) == typing_extensions.Literal
+        and (
+            getattr(thing, "__origin__", None) == typing_extensions.Literal
+            or sys.version_info[:2] == (3, 6)
+            and isinstance(thing, type(typing_extensions.Literal[None]))
+        )
     )
 
 
@@ -348,6 +353,8 @@ _global_type_lookup = {
     os.PathLike: st.builds(PurePath, st.text()),
     # Pull requests with more types welcome!
 }
+if zoneinfo is not None:  # pragma: no branch
+    _global_type_lookup[zoneinfo.ZoneInfo] = st.timezones()
 
 _global_type_lookup[type] = st.sampled_from(
     [type(None)] + sorted(_global_type_lookup, key=str)
@@ -420,9 +427,7 @@ _global_type_lookup.update(
             st.uuids(),
             st.decimals(),
             # this generates strings that should able to be parsed into integers
-            st.from_regex(r"-?\d+", fullmatch=True).filter(
-                lambda value: can_cast(int, value)
-            ),
+            st.from_regex(r"\A-?\d+\Z").filter(functools.partial(can_cast, int)),
         ),
         typing.SupportsBytes: st.one_of(
             st.booleans(),
